@@ -98,7 +98,16 @@ CpB_RW <- function(tree, n, mat, adj, method = "multisite", criterion = "my", pB
     } else {
       # If its a node branch
       # Which species share those nodes
-      spps_node <- names(which(tree$node_matrix[as.character(x), ] > 0))  # node 1    x <- 689
+      # Creating a index
+      spps_node <- NA
+      z <- 1
+      # Filling it
+      for(y in 1:length(tree$paths)){ # y <- 1
+        if(x %in% tree$paths[[y]]){
+          spps_node[z] <- names(tree$paths[y])
+          z <- z + 1
+        }
+      }
 
       # Capturing the range size denominator from the node
       if(length(spps_node) == 1){
@@ -112,7 +121,6 @@ CpB_RW <- function(tree, n, mat, adj, method = "multisite", criterion = "my", pB
     return(deno)
   })
 
-
   ## Calculating the CpB_RW (using phylo-Sorensen) -----------------------------
   # The user wants to use more CPU cores?
   if(ncor > 0){
@@ -138,48 +146,20 @@ CpB_RW <- function(tree, n, mat, adj, method = "multisite", criterion = "my", pB
         commus_nodes <- apply(commu, 1, function(x) { # x <- 1
           # Which species are present in my assemblage
           present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-          # Which is the species position in my node matrix
-          spps <- which(colnames(tree$node_matrix) %in% present_obs)
-
-          # if there is a single spp
-          if(length(spps) == 1){
-            # Which nodes give origin to my species
-            nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[,spps])) > 0)))
-
-          } else {
-            # Which nodes give origin to my species
-            nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-          }
-
-          # Lines from the edge.length to preserve
-          lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                               tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
+          # Which nodes give origin to my species
+          nodes <- unique(unlist(tree$paths[present_obs]))
+          # Obtaining the tips and node positions
+          lines_prs <- which(tree$edge[,2] %in% c(nodes))
 
         })
         # PWR
         p_commus_nodes <- lapply(1:nrow(comb_commus), function(x) { # x <- 1
           # Which species are present in my assemblage
           present_obs <- species[comb_commus[x,] > 0] # present_obs <- species[comb_commus[1,] > 0]
-
-          # Which is the species position in my node matrix
-          spps <- which(colnames(tree$node_matrix) %in% present_obs)
-
-
-          # if there is a single spp
-          if(length(spps) == 1){
-            # Which nodes give origin to my species
-            nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[,spps])) > 0)))
-
-          } else {
-            # Which nodes give origin to my species
-            nodes <- as.numeric(names(which(rowSums(tree$node_matrix[, spps]) > 0)))
-          }
-
-          # Lines from the edge.length to preserve
-          lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                               tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+          # Which nodes give origin to my species
+          nodes <- unique(unlist(tree$paths[present_obs]))
+          # Obtaining the tips and node positions
+          lines_prs <- which(tree$edge[,2] %in% c(nodes))
         })
 
 
@@ -212,15 +192,10 @@ CpB_RW <- function(tree, n, mat, adj, method = "multisite", criterion = "my", pB
           t_commus_nodes <- apply(t(as.matrix(colSums(commu) > 0)), 1, function(x) { # x <- 1
             # Which species are present in my assemblage
             present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-            # Which is the species position in my node matrix
-            spps <- which(colnames(tree$node_matrix) %in% present_obs)
             # Which nodes give origin to my species
-            nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-
-            # Lines from the edge.length to preserve
-            lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                 tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
+            nodes <- unique(unlist(tree$paths[present_obs]))
+            # Obtaining the tips and node positions
+            lines_prs <- which(tree$edge[,2] %in% c(nodes))
 
           })
           # Calculating the total PD for the complete tree
@@ -308,48 +283,19 @@ CpB_RW <- function(tree, n, mat, adj, method = "multisite", criterion = "my", pB
         commus_nodes <- apply(commu, 1, function(x) { # x <- 1
           # Which species are present in my assemblage
           present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-          # Which is the species position in my node matrix
-          spps <- which(colnames(tree$node_matrix) %in% present_obs)
-
-          # if there is a single spp
-          if(length(spps) == 1){
-            # Which nodes give origin to my species
-            nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[,spps])) > 0)))
-
-          } else {
-            # Which nodes give origin to my species
-            nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-          }
-
-          # Lines from the edge.length to preserve
-          lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                               tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+          # Which nodes give origin to my species
+          nodes <- unique(unlist(tree$paths[present_obs]))
+          # Obtaining the tips and node positions
+          lines_prs <- which(tree$edge[,2] %in% c(nodes))
         })
         # PWR
         p_commus_nodes <- lapply(1:nrow(comb_commus), function(x) { # x <- 1
           # Which species are present in my assemblage
           present_obs <- species[comb_commus[x,] > 0] # present_obs <- species[comb_commus[1,] > 0]
-
-          # Which is the species position in my node matrix
-          spps <- which(colnames(tree$node_matrix) %in% present_obs)
-
-
-          # if there is a single spp
-          if(length(spps) == 1){
-            # Which nodes give origin to my species
-            nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[,spps])) > 0)))
-
-          } else {
-            # Which nodes give origin to my species
-            nodes <- as.numeric(names(which(rowSums(tree$node_matrix[, spps]) > 0)))
-          }
-
-          # Lines from the edge.length to preserve
-          lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                               tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+          # Which nodes give origin to my species
+          nodes <- unique(unlist(tree$paths[present_obs]))
+          # Obtaining the tips and node positions
+          lines_prs <- which(tree$edge[,2] %in% c(nodes))
         })
 
 
@@ -382,16 +328,10 @@ CpB_RW <- function(tree, n, mat, adj, method = "multisite", criterion = "my", pB
           t_commus_nodes <- apply(t(as.matrix(colSums(commu) > 0)), 1, function(x) { # x <- 1
             # Which species are present in my assemblage
             present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-            # Which is the species position in my node matrix
-            spps <- which(colnames(tree$node_matrix) %in% present_obs)
             # Which nodes give origin to my species
-            nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-
-            # Lines from the edge.length to preserve
-            lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                 tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+            nodes <- unique(unlist(tree$paths[present_obs]))
+            # Obtaining the tips and node positions
+            lines_prs <- which(tree$edge[,2] %in% c(nodes))
           })
           # Calculating the total PD for the complete tree
           t_pd_assemblages <- sum(tree$edge.length[t_commus_nodes]/r_sizes[t_commus_nodes])
