@@ -126,19 +126,10 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
             return(CPD)
 
           } else {
-            # Obtaining the node matrix for those species
-            if(length(tips) == 1){
-              #  if there is a single spp, which nodes give origin to my species
-              nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[, tips])) > 0)))
-            }
-
-            if(length(tips) > 1){
-              # Which nodes give origin to my species
-              nodes <- as.numeric(names(which(rowSums(tree$node_matrix[, tips]) > 0)))
-            }
-
+            # Which nodes give origin to my species
+            nodes <- unique(unlist(tree$paths[tips]))
             # Obtaining the tips and node positions
-            positions <- which(tree$edge[,2] %in% c(tips, nodes))
+            positions <- which(tree$edge[,2] %in% c(nodes))
 
             # Calculating the relative PE on each phylo slice
             CPD <- sapply(branch_pieces, function(x){     # x <- branch_pieces[[1800]]
@@ -167,19 +158,10 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
             return(CPD)
 
           } else {
-            # Obtaining the node matrix for those species
-            if(length(tips) == 1){
-              #  if there is a single spp, which nodes give origin to my species
-              nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[, tips])) > 0)))
-            }
-
-            if(length(tips) > 1){
-              # Which nodes give origin to my species
-              nodes <- as.numeric(names(which(rowSums(tree$node_matrix[, tips]) > 0)))
-            }
-
+            # Which nodes give origin to my species
+            nodes <- unique(unlist(tree$paths[tips]))
             # Obtaining the tips and node positions
-            positions <- which(tree$edge[,2] %in% c(tips, nodes))
+            positions <- which(tree$edge[,2] %in% c(nodes))
 
             # Calculating the relative PE on each phylo slice
             CPD <- sapply(branch_pieces, function(x){     # x <- branch_pieces[[1800]]
@@ -250,7 +232,16 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
           } else {
             # If its a node branch
             # Which species share those nodes
-            spps_node <- names(which(tree$node_matrix[as.character(x), ] > 0))  # node 1    x <- 689
+            # Creating a index
+            spps_node <- NA
+            z <- 1
+            # Filling it
+            for(y in 1:length(tree$paths)){ # y <- 1
+              if(x %in% tree$paths[[y]]){
+                spps_node[z] <- names(tree$paths[y])
+                z <- z + 1
+              }
+            }
 
             # Capturing the range size denominator from the node
             if(length(spps_node) == 1){
@@ -281,19 +272,10 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
             return(CPE)
 
           } else {
-            # Obtaining the node matrix for those species
-            if(length(tips) == 1){
-              #  if there is a single spp, which nodes give origin to my species
-              nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[, tips])) > 0)))
-            }
-
-            if(length(tips) > 1){
-              # Which nodes give origin to my species
-              nodes <- as.numeric(names(which(rowSums(tree$node_matrix[, tips]) > 0)))
-            }
-
+            # Which nodes give origin to my species
+            nodes <- unique(unlist(tree$paths[tips]))
             # Obtaining the tips and node positions
-            positions <- which(tree$edge[,2] %in% c(tips, nodes))
+            positions <- which(tree$edge[,2] %in% c(nodes))
 
             # Calculating the relative PE on each phylo slice
             CPE <- sapply(branch_pieces, function(x){     # x <- branch_pieces[[1800]]
@@ -322,19 +304,10 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
             return(CPE)
 
           } else {
-            # Obtaining the node matrix for those species
-            if(length(tips) == 1){
-              #  if there is a single spp, which nodes give origin to my species
-              nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[, tips])) > 0)))
-            }
-
-            if(length(tips) > 1){
-              # Which nodes give origin to my species
-              nodes <- as.numeric(names(which(rowSums(tree$node_matrix[, tips]) > 0)))
-            }
-
+            # Which nodes give origin to my species
+            nodes <- unique(unlist(tree$paths[tips]))
             # Obtaining the tips and node positions
-            positions <- which(tree$edge[,2] %in% c(tips, nodes))
+            positions <- which(tree$edge[,2] %in% c(nodes))
 
             # Calculating the relative PE on each phylo slice
             CPE <- sapply(branch_pieces, function(x){     # x <- branch_pieces[[1800]]
@@ -402,48 +375,19 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
             commus_nodes <- apply(commu, 1, function(x) { # x <- 1
               # Which species are present in my assemblage
               present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-              # Which is the species position in my node matrix
-              spps <- which(colnames(tree$node_matrix) %in% present_obs)
-
-              # if there is a single spp
-              if(length(spps) == 1){
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[,spps])) > 0)))
-
-              } else {
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-              }
-
-              # Lines from the edge.length to preserve
-              lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                   tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+              # Which nodes give origin to my species
+              nodes <- unique(unlist(tree$paths[present_obs]))
+              # Obtaining the tips and node positions
+              lines_prs <- which(tree$edge[,2] %in% c(nodes))
             })
             # PWR
             p_commus_nodes <- lapply(1:nrow(comb_commus), function(x) { # x <- 1
               # Which species are present in my assemblage
               present_obs <- species[comb_commus[x,] > 0] # present_obs <- species[comb_commus[1,] > 0]
-
-              # Which is the species position in my node matrix
-              spps <- which(colnames(tree$node_matrix) %in% present_obs)
-
-
-              # if there is a single spp
-              if(length(spps) == 1){
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[,spps])) > 0)))
-
-              } else {
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(tree$node_matrix[, spps]) > 0)))
-              }
-
-              # Lines from the edge.length to preserve
-              lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                   tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+              # Which nodes give origin to my species
+              nodes <- unique(unlist(tree$paths[present_obs]))
+              # Obtaining the tips and node positions
+              lines_prs <- which(tree$edge[,2] %in% c(nodes))
             })
 
 
@@ -476,16 +420,10 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
                 t_commus_nodes <- apply(t(as.matrix(colSums(commu) > 0)), 1, function(x) { # x <- 1
                   # Which species are present in my assemblage
                   present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-                  # Which is the species position in my node matrix
-                  spps <- which(colnames(tree$node_matrix) %in% present_obs)
                   # Which nodes give origin to my species
-                  nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-
-                  # Lines from the edge.length to preserve
-                  lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                       tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+                  nodes <- unique(unlist(tree$paths[present_obs]))
+                  # Obtaining the tips and node positions
+                  lines_prs <- which(tree$edge[,2] %in% c(nodes))
                 })
                 # Calculating the total PD for the complete tree
                 t_pd_assemblages <- sum(tree$edge.length[t_commus_nodes])
@@ -557,16 +495,10 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
                 t_commus_nodes <- apply(t(as.matrix(colSums(commu) > 0)), 1, function(x) { # x <- 1
                   # Which species are present in my assemblage
                   present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-                  # Which is the species position in my node matrix
-                  spps <- which(colnames(tree$node_matrix) %in% present_obs)
                   # Which nodes give origin to my species
-                  nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-
-                  # Lines from the edge.length to preserve
-                  lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                       tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+                  nodes <- unique(unlist(tree$paths[present_obs]))
+                  # Obtaining the tips and node positions
+                  lines_prs <- which(tree$edge[,2] %in% c(nodes))
                 })
                 # Calculating the total PD for the complete tree
                 t_pd_assemblages <- sum(tree$edge.length[t_commus_nodes])
@@ -628,16 +560,10 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
                 t_commus_nodes <- apply(t(as.matrix(colSums(commu) > 0)), 1, function(x) { # x <- 1
                   # Which species are present in my assemblage
                   present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-                  # Which is the species position in my node matrix
-                  spps <- which(colnames(tree$node_matrix) %in% present_obs)
                   # Which nodes give origin to my species
-                  nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-
-                  # Lines from the edge.length to preserve
-                  lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                       tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+                  nodes <- unique(unlist(tree$paths[present_obs]))
+                  # Obtaining the tips and node positions
+                  lines_prs <- which(tree$edge[,2] %in% c(nodes))
                 })
                 # Calculating the total PD for the complete tree
                 t_pd_assemblages <- sum(tree$edge.length[t_commus_nodes])
@@ -727,48 +653,19 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
             commus_nodes <- apply(commu, 1, function(x) { # x <- 1
               # Which species are present in my assemblage
               present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-              # Which is the species position in my node matrix
-              spps <- which(colnames(tree$node_matrix) %in% present_obs)
-
-              # if there is a single spp
-              if(length(spps) == 1){
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[,spps])) > 0)))
-
-              } else {
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-              }
-
-              # Lines from the edge.length to preserve
-              lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                   tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+              # Which nodes give origin to my species
+              nodes <- unique(unlist(tree$paths[present_obs]))
+              # Obtaining the tips and node positions
+              lines_prs <- which(tree$edge[,2] %in% c(nodes))
             })
             # PWR
             p_commus_nodes <- lapply(1:nrow(comb_commus), function(x) { # x <- 1
               # Which species are present in my assemblage
               present_obs <- species[comb_commus[x,] > 0] # present_obs <- species[comb_commus[1,] > 0]
-
-              # Which is the species position in my node matrix
-              spps <- which(colnames(tree$node_matrix) %in% present_obs)
-
-
-              # if there is a single spp
-              if(length(spps) == 1){
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[,spps])) > 0)))
-
-              } else {
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(tree$node_matrix[, spps]) > 0)))
-              }
-
-              # Lines from the edge.length to preserve
-              lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                   tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+              # Which nodes give origin to my species
+              nodes <- unique(unlist(tree$paths[present_obs]))
+              # Obtaining the tips and node positions
+              lines_prs <- which(tree$edge[,2] %in% c(nodes))
             })
 
 
@@ -801,16 +698,10 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
                 t_commus_nodes <- apply(t(as.matrix(colSums(commu) > 0)), 1, function(x) { # x <- 1
                   # Which species are present in my assemblage
                   present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-                  # Which is the species position in my node matrix
-                  spps <- which(colnames(tree$node_matrix) %in% present_obs)
                   # Which nodes give origin to my species
-                  nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-
-                  # Lines from the edge.length to preserve
-                  lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                       tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+                  nodes <- unique(unlist(tree$paths[present_obs]))
+                  # Obtaining the tips and node positions
+                  lines_prs <- which(tree$edge[,2] %in% c(nodes))
                 })
                 # Calculating the total PD for the complete tree
                 t_pd_assemblages <- sum(tree$edge.length[t_commus_nodes])
@@ -882,16 +773,10 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
                 t_commus_nodes <- apply(t(as.matrix(colSums(commu) > 0)), 1, function(x) { # x <- 1
                   # Which species are present in my assemblage
                   present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-                  # Which is the species position in my node matrix
-                  spps <- which(colnames(tree$node_matrix) %in% present_obs)
                   # Which nodes give origin to my species
-                  nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-
-                  # Lines from the edge.length to preserve
-                  lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                       tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+                  nodes <- unique(unlist(tree$paths[present_obs]))
+                  # Obtaining the tips and node positions
+                  lines_prs <- which(tree$edge[,2] %in% c(nodes))
                 })
                 # Calculating the total PD for the complete tree
                 t_pd_assemblages <- sum(tree$edge.length[t_commus_nodes])
@@ -953,16 +838,10 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
                 t_commus_nodes <- apply(t(as.matrix(colSums(commu) > 0)), 1, function(x) { # x <- 1
                   # Which species are present in my assemblage
                   present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-                  # Which is the species position in my node matrix
-                  spps <- which(colnames(tree$node_matrix) %in% present_obs)
                   # Which nodes give origin to my species
-                  nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-
-                  # Lines from the edge.length to preserve
-                  lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                       tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+                  nodes <- unique(unlist(tree$paths[present_obs]))
+                  # Obtaining the tips and node positions
+                  lines_prs <- which(tree$edge[,2] %in% c(nodes))
                 })
                 # Calculating the total PD for the complete tree
                 t_pd_assemblages <- sum(tree$edge.length[t_commus_nodes])
@@ -1085,7 +964,16 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
         } else {
           # If its a node branch
           # Which species share those nodes
-          spps_node <- names(which(tree$node_matrix[as.character(x), ] > 0))  # node 1    x <- 689
+          # Creating a index
+          spps_node <- NA
+          z <- 1
+          # Filling it
+          for(y in 1:length(tree$paths)){ # y <- 1
+            if(x %in% tree$paths[[y]]){
+              spps_node[z] <- names(tree$paths[y])
+              z <- z + 1
+            }
+          }
 
           # Capturing the range size denominator from the node
           if(length(spps_node) == 1){
@@ -1099,7 +987,6 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
         return(deno)
       })
 
-
       ## Calculating the CpB_RW (using phylo-Sorensen) -----------------------------
       # The user wants to use more CPU cores?
       if(ncor > 0){
@@ -1125,48 +1012,19 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
             commus_nodes <- apply(commu, 1, function(x) { # x <- 1
               # Which species are present in my assemblage
               present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-              # Which is the species position in my node matrix
-              spps <- which(colnames(tree$node_matrix) %in% present_obs)
-
-              # if there is a single spp
-              if(length(spps) == 1){
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[,spps])) > 0)))
-
-              } else {
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-              }
-
-              # Lines from the edge.length to preserve
-              lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                   tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+              # Which nodes give origin to my species
+              nodes <- unique(unlist(tree$paths[present_obs]))
+              # Obtaining the tips and node positions
+              lines_prs <- which(tree$edge[,2] %in% c(nodes))
             })
             # PWR
             p_commus_nodes <- lapply(1:nrow(comb_commus), function(x) { # x <- 1
               # Which species are present in my assemblage
               present_obs <- species[comb_commus[x,] > 0] # present_obs <- species[comb_commus[1,] > 0]
-
-              # Which is the species position in my node matrix
-              spps <- which(colnames(tree$node_matrix) %in% present_obs)
-
-
-              # if there is a single spp
-              if(length(spps) == 1){
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[,spps])) > 0)))
-
-              } else {
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(tree$node_matrix[, spps]) > 0)))
-              }
-
-              # Lines from the edge.length to preserve
-              lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                   tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+              # Which nodes give origin to my species
+              nodes <- unique(unlist(tree$paths[present_obs]))
+              # Obtaining the tips and node positions
+              lines_prs <- which(tree$edge[,2] %in% c(nodes))
             })
 
 
@@ -1199,16 +1057,10 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
               t_commus_nodes <- apply(t(as.matrix(colSums(commu) > 0)), 1, function(x) { # x <- 1
                 # Which species are present in my assemblage
                 present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-                # Which is the species position in my node matrix
-                spps <- which(colnames(tree$node_matrix) %in% present_obs)
                 # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-
-                # Lines from the edge.length to preserve
-                lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                     tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+                nodes <- unique(unlist(tree$paths[present_obs]))
+                # Obtaining the tips and node positions
+                lines_prs <- which(tree$edge[,2] %in% c(nodes))
               })
               # Calculating the total PD for the complete tree
               t_pd_assemblages <- sum(tree$edge.length[t_commus_nodes]/r_sizes[t_commus_nodes])
@@ -1280,48 +1132,19 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
             commus_nodes <- apply(commu, 1, function(x) { # x <- 1
               # Which species are present in my assemblage
               present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-              # Which is the species position in my node matrix
-              spps <- which(colnames(tree$node_matrix) %in% present_obs)
-
-              # if there is a single spp
-              if(length(spps) == 1){
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[,spps])) > 0)))
-
-              } else {
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-              }
-
-              # Lines from the edge.length to preserve
-              lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                   tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+              # Which nodes give origin to my species
+              nodes <- unique(unlist(tree$paths[present_obs]))
+              # Obtaining the tips and node positions
+              lines_prs <- which(tree$edge[,2] %in% c(nodes))
             })
             # PWR
             p_commus_nodes <- lapply(1:nrow(comb_commus), function(x) { # x <- 1
               # Which species are present in my assemblage
               present_obs <- species[comb_commus[x,] > 0] # present_obs <- species[comb_commus[1,] > 0]
-
-              # Which is the species position in my node matrix
-              spps <- which(colnames(tree$node_matrix) %in% present_obs)
-
-
-              # if there is a single spp
-              if(length(spps) == 1){
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(as.data.frame(tree$node_matrix[,spps])) > 0)))
-
-              } else {
-                # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(tree$node_matrix[, spps]) > 0)))
-              }
-
-              # Lines from the edge.length to preserve
-              lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                   tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+              # Which nodes give origin to my species
+              nodes <- unique(unlist(tree$paths[present_obs]))
+              # Obtaining the tips and node positions
+              lines_prs <- which(tree$edge[,2] %in% c(nodes))
             })
 
 
@@ -1354,16 +1177,10 @@ r_phylo <- function(tree, n, mat, adj, index = NULL, comp = "sorensen",
               t_commus_nodes <- apply(t(as.matrix(colSums(commu) > 0)), 1, function(x) { # x <- 1
                 # Which species are present in my assemblage
                 present_obs <- species[x > 0] # present_obs <- species[commu[1,] > 0]
-
-                # Which is the species position in my node matrix
-                spps <- which(colnames(tree$node_matrix) %in% present_obs)
                 # Which nodes give origin to my species
-                nodes <- as.numeric(names(which(rowSums(tree$node_matrix[,spps]) > 0)))
-
-                # Lines from the edge.length to preserve
-                lines_prs <- which(tree$edge[, 1] %in% nodes &             # Which nodes are in my spliting side from matrix
-                                     tree$edge[, 2] %in% c(spps, nodes))   # Which nodes and tips are in my splitted side from matrix
-
+                nodes <- unique(unlist(tree$paths[present_obs]))
+                # Obtaining the tips and node positions
+                lines_prs <- which(tree$edge[,2] %in% c(nodes))
               })
               # Calculating the total PD for the complete tree
               t_pd_assemblages <- sum(tree$edge.length[t_commus_nodes]/r_sizes[t_commus_nodes])
